package schema

import (
	"wechat-api/ent/schema/localmixin"

	"entgo.io/ent"
	"entgo.io/ent/dialect/entsql"
	"entgo.io/ent/schema"
	"entgo.io/ent/schema/field"
	"github.com/suyuan32/simple-admin-common/orm/ent/mixins"
)

type Agent struct {
	ent.Schema
}

func (Agent) Fields() []ent.Field {
	return []ent.Field{
		field.String("name").MaxLen(20).Comment("name | 角色名称"),
		field.String("role").MaxLen(1000).Comment("role | 角色设定"),
		field.Int("status").Optional().Default(1).Comment("status | 状态 1-正常 2-禁用"),
		field.String("background").MaxLen(1000).Comment("background | 背景介绍"),
		field.String("examples").MaxLen(5000).Comment("examples | 对话案例"),
		field.Uint64("organization_id").Comment("organization_id | 租户ID"),
	}
}

func (Agent) Mixin() []ent.Mixin {
	return []ent.Mixin{
		mixins.IDMixin{},
		localmixin.SoftDeleteMixin{},
	}
}

func (Agent) Edges() []ent.Edge {
	return nil
}

func (Agent) Indexes() []ent.Index {
	return []ent.Index{}
}

func (Agent) Annotations() []schema.Annotation {
	return []schema.Annotation{
		entsql.WithComments(true),
		entsql.Annotation{Table: "agent"},
	}
}
